Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(262)

Unified Diff: src/spaces.h

Issue 174050: Temporarily revert the reduction of semispace sizes and the growth... (Closed) Base URL: http://v8.googlecode.com/svn/branches/bleeding_edge/
Patch Set: Created 11 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/heap.cc ('k') | src/spaces.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/spaces.h
===================================================================
--- src/spaces.h (revision 2711)
+++ src/spaces.h (working copy)
@@ -1004,11 +1004,11 @@
// True if the space has been set up but not torn down.
bool HasBeenSetup() { return start_ != NULL; }
// Grow the size of the semispace by committing extra virtual memory.
// Assumes that the caller has checked that the semispace has not reached
// its maximum capacity (and thus there is space available in the reserved
// address range to grow).
- bool Grow();
+ bool Double();
// Returns the start address of the space.
Address low() { return start_; }
@@ -1051,9 +1051,6 @@
virtual void Verify();
#endif
- // Returns the current capacity of the semi space.
- int Capacity() { return capacity_; }
-
private:
// The current and maximum capacity of the space.
int capacity_;
@@ -1147,9 +1144,9 @@
// Flip the pair of spaces.
void Flip();
- // Grow the capacity of the semispaces. Assumes that they are not at
+ // Doubles the capacity of the semispaces. Assumes that they are not at
// their maximum capacity. Returns a flag indicating success or failure.
- bool Grow();
+ bool Double();
// True if the address or object lies in the address range of either
// semispace (not necessarily below the allocation pointer).
« no previous file with comments | « src/heap.cc ('k') | src/spaces.cc » ('j') | no next file with comments »
@@ -1004,11 +1004,11 @@
// True if the space has been set up but not torn down.
bool HasBeenSetup() { return start_ != NULL; }
- // Grow the size of the semispace by committing extra virtual memory.
+ // Double the size of the semispace by committing extra virtual memory.
// Assumes that the caller has checked that the semispace has not reached
// its maximum capacity (and thus there is space available in the reserved

Powered by Google App Engine
This is Rietveld 408576698